==> xlr-ui-22.3.14.jar: web/react/components/configuration-delete-reference/configuration-delete-reference.component.js <==
import React from 'react';
import { DotThemeProvider, DotTable, DotLink } from '@digital-ai/dot-components';
import PropTypes from 'prop-types';

export const ConfigurationDeleteReferenceComponent = ({ data, responseMessage }) => {
    const getCiReferenceLink = (reference) => {
        switch (true) {
            case reference.referenceType.includes('Release'):
                const formRelease = reference.id.split('/');
                return `#/releases/${formRelease[1]}-${formRelease[2]}`;
            case reference.referenceType.includes('Template'):
                const formTemplate = reference.id.split('/');
                return `#/templates/${formTemplate[1]}-${formTemplate[2]}`;
            case reference.referenceType.includes('Trigger'):
                const formTrigger = reference.id.split('/');
                return `#/trigger-management/${formTrigger[2]}?folderId=${formTrigger[0]}/${formTrigger[1]}`;
            default:
                return '';
        }
    };

    const getConfigurationReferenceData = () => {
        const tableData = [];
        data.forEach((reference) => {
            const link = getCiReferenceLink(reference);
            const warningData = {
                id: reference.id,
                rowData: {
                    title: reference.title,
                    link: (
                        <DotLink href={link} target="_blank">
                            Click Here
                        </DotLink>
                    ),
                },
            };
            tableData.push(warningData);
        });
        return tableData;
    };

    const columns = () => {
        return [
            {
                id: 'title',
                label: 'Title',
                width: '50%',
            },
            {
                id: 'link',
                label: 'Referenced at',
                width: '50%',
            },
        ];
    };

    return data.length !== 0 ? (
        <DotThemeProvider>
            <DotTable columns={columns()} data={getConfigurationReferenceData()} maxHeight="100%" order="asc" orderBy="title" rowsPerPage={8} />
        </DotThemeProvider>
    ) : (
        <div>
            <p>{responseMessage}</p>
        </div>
    );
};

ConfigurationDeleteReferenceComponent.propTypes = {
    data: PropTypes.arrayOf(
        PropTypes.shape({
            id: PropTypes.string,
            title: PropTypes.string,
        }),
    ),
    responseMessage: PropTypes.string,
};

==> xlr-ui-24.1.0.jar: web/react/components/configuration-delete-reference/configuration-delete-reference.component.js <==
import React from 'react';
import { DotThemeProvider, DotTable, DotLink } from '@digital-ai/dot-components';
import PropTypes from 'prop-types';
import IdsFactory from '../../../js/util/ids';

export const ConfigurationDeleteReferenceComponent = ({ data, responseMessage }) => {
    const getCiReferenceLink = (reference) => {
        switch (true) {
            case reference.referenceType.includes('Release'):
                const formRelease = reference.id.split('/');
                return `#/releases/${formRelease[1]}-${formRelease[2]}`;
            case reference.referenceType.includes('Task'):
                const releaseId = IdsFactory().releaseIdFrom(reference.id);
                const phaseTaskId = IdsFactory().phaseTaskIdFrom(reference.id);
                const internalId = IdsFactory().toInternalId(phaseTaskId);
                return `#/releases/${releaseId}?openTaskDetailsModal=${internalId}`;
            case reference.referenceType.includes('Template'):
                const formTemplate = reference.id.split('/');
                return `#/templates/${formTemplate[1]}-${formTemplate[2]}`;
            case reference.referenceType.includes('Trigger'):
                const formTrigger = reference.id.split('/');
                return `#/trigger-management/${formTrigger[2]}?folderId=${formTrigger[0]}/${formTrigger[1]}`;
            default:
                return '';
        }
    };

    const getConfigurationReferenceData = () => {
        const tableData = [];
        data.forEach((reference) => {
            const link = getCiReferenceLink(reference);
            const warningData = {
                id: reference.id,
                rowData: {
                    title: reference.title,
                    link: (
                        <DotLink href={link} target="_self">
                            Click Here
                        </DotLink>
                    ),
                },
            };
            tableData.push(warningData);
        });
        return tableData;
    };

    const columns = () => {
        return [
            {
                id: 'title',
                label: 'Title',
                width: '50%',
            },
            {
                id: 'link',
                label: 'Referenced at',
                width: '50%',
            },
        ];
    };

    return data.length !== 0 ? (
        <DotThemeProvider>
            <DotTable columns={columns()} data={getConfigurationReferenceData()} maxHeight="100%" order="asc" orderBy="title" rowsPerPage={8} />
        </DotThemeProvider>
    ) : (
        <div>
            <p>{responseMessage}</p>
        </div>
    );
};

ConfigurationDeleteReferenceComponent.propTypes = {
    data: PropTypes.arrayOf(
        PropTypes.shape({
            id: PropTypes.string,
            title: PropTypes.string,
        }),
    ),
    responseMessage: PropTypes.string,
};
